@@ -187,7 +187,12 @@ if (! window._OQAjaxQueryLoaded)
   });
 
   $(document).delegate('.OQToolsBut','click', function(){
-    $(".OQToolsPanel").toggle().filter(':visible').find('li:first h3').click();
+    var $p = $(".OQToolsPanel").toggle();
+
+    // open export by default
+    if ($p.is(':visible')) {
+      $p.find("li[data-toolkey=export]:not(.opened) > h3").click();
+    }
   });
 
   $(document).delegate('.OQDeleteSavedSearchBut','click', function(){
@@ -341,18 +346,23 @@ if (! window._OQAjaxQueryLoaded)
   });
 
   $(document).delegate('.OQToolExpander h3', 'click', function() {
-    var $t = $(this).closest('li');
-    var $content = $t.closest('.OQToolsPanel').find('.OQToolContent');
-    $content.remove();
-    $content.closest('li').removeClass('opened');
-    $t.addClass('opened'); 
-    var $newtoolcontent = $("<div class=OQToolContent />");
-    $t.append($newtoolcontent);
-    var $f = $('form.OQform');
-    var dat = buildParamMap($f);
-    dat.module = 'InteractiveQuery2Tools';
-    dat.tool = $t.attr('data-toolkey');
-    $newtoolcontent.load($f[0].action, dat);
+    var $newli = $(this).closest('li');
+
+    var $oldcontent = $newli.closest('.OQToolsPanel').find('.OQToolContent');
+    var $oldli = $oldcontent.closest('li').removeClass('opened');
+    $oldcontent.remove();
+
+    // load tool panel content
+    if ($newli[0] != $oldli[0]) {
+      $newli.addClass('opened'); 
+      var $newcontent = $("<div class=OQToolContent />");
+      $newli.append($newcontent);
+      var $f = $('form.OQform');
+      var dat = buildParamMap($f);
+      dat.module = 'InteractiveQuery2Tools';
+      dat.tool = $newli.attr('data-toolkey');
+      $newcontent.load($f[0].action, dat);
+    }
   });
 
   $(document).delegate('.OQFilterDescr', 'click', function() {
@@ -488,9 +498,14 @@ if (! window._OQAjaxQueryLoaded)
   $(document.body).delegate('.OQeditBut,.OQnewBut', 'click', function(){
     var $t = $(this);
     var href = $t.attr('data-href') || $t.attr('href');
-    OQopwin(href);
+    var target = $t.attr('data-target') || $t.attr('target');
+    if (target) OQopwin(href,target);
+    else if (window.OQusePopups) OQopwin(href);
+    else if ($t.is("button")) location = href;
+    else return true;  // follow link as normal 
     return false;
   });
+
   $(document.body).delegate('.OQselectBut', 'click', function(){
     var f = this.form;
     var args = $(this).attr('data-rv');
@@ -732,25 +747,44 @@ if (! window._OQAjaxQueryLoaded)
   var refreshDataGrid = function($f,dat) {
     $f.addClass('LoadingData');
     if (! dat) dat = buildParamMap($f);
-    dat.dataonly = 1;
-    dat.module = 'InteractiveQuery2';
-    return $.ajax({
-      url: $f[0].action, type: 'POST', data: dat, dataType: 'html',
-      error: function() {
-        alert('Could not load data for data grid after error.');
-        $f.removeClass('LoadingData');
-      },
-      success: function(d) {
-        try {
-          var $p = $('<div>').append(d).find('form.OQform');
-          if ($p.length!=1) throw(1);
-          $f.replaceWith($p);
-        } catch(e) {
-          alert('Could not load data for data grid after success.');
+
+    // load OQ data using ajax
+    if (window.OQuseAjax) {
+      dat.dataonly = 1;
+      dat.module = 'InteractiveQuery2';
+      return $.ajax({
+        url: $f[0].action, type: 'POST', data: dat, dataType: 'html',
+        error: function() {
+          alert('Could not load data for data grid after error.');
           $f.removeClass('LoadingData');
+        },
+        success: function(d) {
+          try {
+            var $p = $('<div>').append(d).find('form.OQform');
+            if ($p.length!=1) throw(1);
+            $f.replaceWith($p);
+          } catch(e) {
+            alert('Could not load data for data grid after success.');
+            $f.removeClass('LoadingData');
+          }
         }
+      });
+    }
+
+    // reload data by reloading entire page
+    else {
+      // merge form get args
+      var urlargs = $f.attr('action').split(/\?/);
+      if (urlargs[1]) {
+        $.each(urlargs[1].split(/[\&\;]/), function() {
+          var kv = this.split(/\=/);
+          if (! dat[kv[0]]) dat[kv[0]]=kv[1];
+        });
       }
-    });
+    
+      var newUrl = urlargs[0]+'?'+$.param(dat);
+      location = newUrl;
+    }
   };
 
   window.OQrefresh = function(updated_uid) {
@@ -778,6 +812,8 @@ if (! window._OQAjaxQueryLoaded)
     }
   };
 
+  
+
   if (window.opwin) window.OQopwin=window.opwin;
   else window.OQopwin = function(lnk,target,opts,w,h) {
     if (! target) target = '_blank';
